@@ -22,8 +22,7 @@ from typing import (
 
 from robotcode.core.async_itertools import async_dropwhile, async_takewhile
 from robotcode.core.logging import LoggingDescriptor
-from robotcode.language_server.common.decorators import language_id
-from robotcode.language_server.common.lsp_types import (
+from robotcode.core.lsp.types import (
     Position,
     Range,
     SemanticTokenModifiers,
@@ -33,6 +32,7 @@ from robotcode.language_server.common.lsp_types import (
     SemanticTokensPartialResult,
     SemanticTokenTypes,
 )
+from robotcode.language_server.common.decorators import language_id
 from robotcode.language_server.common.text_document import TextDocument, range_to_utf16
 from robotcode.language_server.robotframework.diagnostics.library_doc import (
     ALL_RUN_KEYWORDS_MATCHERS,
